@@ -1,4 +1,5 @@
 # pylint: disable=protected-access
+from __future__ import annotations
 
 import re
 from functools import wraps
@@ -16,6 +17,7 @@ from . import __version__
 from .environment import running_in_pytest
 from .errors import (
     AdminOnlyError,
+    GuildOnlyError,
     UserBannedError,
     UserUnverifiedError,
     UserVerifiedError,
@@ -48,9 +50,9 @@ def no_metrics() -> bool:
     )
 
 
-def skip_if_no_metrics(f) -> Callable[..., None]:  # pragma: no cover
+def skip_if_no_metrics(f: Any) -> Callable[..., None]:  # pragma: no cover
     @wraps(f)
-    def wrapper(*args, **kwargs) -> None:
+    def wrapper(*args: Any, **kwargs: Any) -> None:
         return None if no_metrics() else f(*args, **kwargs)
 
     return wrapper
@@ -61,7 +63,7 @@ def patch_discord() -> None:  # pragma: no cover
     interaction_callback = re.compile(r"/interactions/([0-9]+)/([^/]+)/callback")
     webhook_message = re.compile(r"/webhooks/([0-9]+)/([^/]+)/messages/@original")
 
-    def request(wrapped: Callable, instance, args, kwargs):  # pragma: no cover
+    def request(wrapped: Callable, instance, args, kwargs):  # type: ignore # pragma: no cover
         route: Route = args[0]
         path: str = route.path
         additional_tags = {}
@@ -70,18 +72,12 @@ def patch_discord() -> None:  # pragma: no cover
             additional_tags["interaction_id"] = matches[1]
             additional_tags["interaction_token"] = matches[2]
         elif matches := webhook_message.match(path):
-            resource = (
-                r"/webhooks/{application_id}/{interaction_token}/messages/@original"
-            )
+            resource = r"/webhooks/{application_id}/{interaction_token}/messages/@original"
             additional_tags["application_id"] = matches[1]
             additional_tags["interaction_token"] = matches[2]
         else:
             resource = path
-        with tracer.trace(  # type: ignore
-            service="discord",
-            name="http",
-            resource=resource,
-        ) as span:
+        with tracer.trace(service="discord", name="http", resource=resource) as span:
             span.set_tags(
                 {
                     "base": route.BASE,
@@ -116,10 +112,10 @@ def alert_error(
 
 
 @skip_if_no_metrics
-def add_span_context(ctx: Any):  # pragma: no cover
+def add_span_context(interaction: Any):  # pragma: no cover
     if span := tracer.current_span():
         for prop in CTX_PROPS:
-            if value := getattr(ctx, prop, None):
+            if value := getattr(interaction, prop, None):
                 span.set_tag(prop, value)
 
 
@@ -140,7 +136,8 @@ def add_span_error(ex: BaseException):  # pragma: no cover
 
 @skip_if_no_metrics
 def setup_ignored_errors(span: Span):  # pragma: no cover
-    span._ignore_exception(UserBannedError)  # type: ignore
-    span._ignore_exception(UserVerifiedError)  # type: ignore
-    span._ignore_exception(UserUnverifiedError)  # type: ignore
     span._ignore_exception(AdminOnlyError)  # type: ignore
+    span._ignore_exception(GuildOnlyError)  # type: ignore
+    span._ignore_exception(UserBannedError)  # type: ignore
+    span._ignore_exception(UserUnverifiedError)  # type: ignore
+    span._ignore_exception(UserVerifiedError)  # type: ignore
