@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 from collections import namedtuple
 from datetime import datetime
 from enum import Enum, auto
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Any, Optional
 
 import discord
 from dateutil import tz
@@ -28,7 +30,7 @@ FormatDetails = namedtuple("FormatDetails", ["players"])
 class GameFormat(Enum):
     """A Magic: The Gathering game format."""
 
-    def __new__(cls, *args, **kwargs):  # pylint: disable=W0613
+    def __new__(cls, *args: Any, **kwargs: Any):  # pylint: disable=W0613
         """Give each enum value an increasing numerical value starting at 1."""
         value = len(cls.__members__) + 1
         obj = object.__new__(cls)
@@ -186,9 +188,7 @@ class Game(Base):
     def embed_description(self, dm: bool = False) -> str:
         description = ""
         if self.status == GameStatus.PENDING.value:
-            description += (
-                "_A SpellTable link will be created when all players have joined._"
-            )
+            description += "_A SpellTable link will be created when all players have joined._"
         else:
             if self.show_links(dm):
                 if self.spelltable_link:
@@ -210,18 +210,14 @@ class Game(Base):
                         f" (invite will expire in {expire_min} minutes)"
                     )
             else:
-                description += (
-                    "Please check your Direct Messages for your SpellTable link."
-                )
+                description += "Please check your Direct Messages for your SpellTable link."
             if dm:
                 description += (
                     "\n\nYou can also [jump to the original game post]"
                     f"({self.jump_link}) in <#{self.channel_xid}>."
                 )
             elif self.guild.show_points:
-                description += (
-                    "\n\nWhen your game is over use the drop down to report your points."
-                )
+                description += "\n\nWhen your game is over use the drop down to report your points."
         if self.guild.motd:
             description += f"\n\n{self.guild.motd}"
         if self.channel.motd:
@@ -283,7 +279,7 @@ class Game(Base):
         embed.color = discord.Color(settings.EMBED_COLOR)
         return embed
 
-    def to_dict(self) -> dict:
+    def to_dict(self) -> dict[str, Any]:
         return {
             "id": self.id,
             "created_at": self.created_at,
