@@ -1,23 +1,32 @@
+from __future__ import annotations
+
 import logging
-from typing import Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Optional, Union, cast
 
 import discord
 from ddtrace import tracer
 from discord.errors import DiscordException
-from discord_slash.context import ComponentContext, InteractionContext
 
 from .metrics import add_span_error
 from .utils import (
     CANT_SEND_CODE,
-    DiscordChannel,
     bot_can_delete_channel,
     bot_can_read,
     bot_can_reply_to,
     bot_can_role,
+    log_info,
     log_warning,
     suppress,
 )
 
+if TYPE_CHECKING:
+    from discord.abc import MessageableChannel, PrivateChannel
+    from discord.guild import GuildChannel
+    from discord.threads import Thread
+
+    # Good god why does discord.py type hinting suck so much ass?
+    GetChannelReturnType = Optional[Union[GuildChannel, Thread, PrivateChannel]]
+
 logger = logging.getLogger(__name__)
 bad_users: set[int] = set()
 
@@ -74,7 +83,7 @@ async def safe_fetch_text_channel(
         span.set_tags({"guild_xid": str(guild_xid), "channel_xid": str(channel_xid)})
 
     # first check our channel cache
-    channel: Optional[DiscordChannel]
+    channel: GetChannelReturnType
     if channel := client.get_channel(channel_xid):
         if not isinstance(channel, discord.TextChannel):
             return None
@@ -97,17 +106,14 @@ async def safe_fetch_text_channel(
 
 @tracer.wrap()
 def safe_get_partial_message(
-    channel: DiscordChannel,
+    channel: MessageableChannel,
     guild_xid: int,
     message_xid: int,
 ) -> Optional[discord.PartialMessage]:
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags({"guild_xid": str(guild_xid), "message_xid": str(message_xid)})
 
-    if (
-        not hasattr(channel, "type")
-        or getattr(channel, "type") != discord.ChannelType.text
-    ):
+    if not hasattr(channel, "type") or getattr(channel, "type") != discord.ChannelType.text:
         return None
 
     if not bot_can_read(channel):
@@ -128,8 +134,8 @@ def safe_get_partial_message(
 @tracer.wrap()
 async def safe_update_embed(
     message: Union[discord.Message, discord.PartialMessage],
-    *args,
-    **kwargs,
+    *args: Any,
+    **kwargs: Any,
 ) -> bool:
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags({"messsage_xid": str(message.id)})
@@ -146,19 +152,24 @@ async def safe_update_embed(
 
 
 @tracer.wrap()
-async def safe_update_embed_origin(ctx: ComponentContext, *args, **kwargs) -> bool:
-    assert hasattr(ctx, "origin_message_id")
+async def safe_update_embed_origin(
+    interaction: discord.Interaction,
+    *args: Any,
+    **kwargs: Any,
+) -> bool:
+    assert hasattr(interaction, "message")
+    assert interaction.message
 
     if span := tracer.current_span():  # pragma: no cover
-        span.set_tags({"origin_messsage_xid": str(ctx.origin_message_id)})
+        span.set_tags({"interaction.message.id": str(interaction.message.id)})
 
     success: bool = False
     with suppress(
         DiscordException,
         log="could not update origin embed in message %(message_xid)s",
-        message_xid=ctx.origin_message_id,
+        message_xid=interaction.message.id,
     ):
-        await ctx.edit_origin(*args, **kwargs)
+        await interaction.edit_original_response(*args, **kwargs)
         success = True
     return success
 
@@ -284,7 +295,7 @@ async def safe_create_invite(
 
 @tracer.wrap()
 async def safe_delete_channel(
-    channel: discord.abc.GuildChannel,
+    channel: MessageableChannel,
     guild_xid: int,
 ) -> bool:
     if span := tracer.current_span():  # pragma: no cover
@@ -296,6 +307,9 @@ async def safe_delete_channel(
     if not hasattr(channel, "id"):
         return False
 
+    if not hasattr(channel, "delete"):
+        return False
+
     channel_xid: int = getattr(channel, "id")
     if span:  # pragma: no cover
         span.set_tag("channel_xid", channel_xid)
@@ -307,22 +321,22 @@ async def safe_delete_channel(
         guild_xid=guild_xid,
         channel_xid=channel_xid,
     ):
-        await channel.delete()
+        await channel.delete()  # type: ignore
         success = True
     return success
 
 
 @tracer.wrap()
 async def safe_send_channel(
-    ctx: InteractionContext,
-    *args,
-    **kwargs,
+    interaction: discord.Interaction,
+    *args: Any,
+    **kwargs: Any,
 ) -> Optional[discord.Message]:
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags(
             {
-                "guild_xid": str(ctx.guild_id),
-                "channel_xid": str(ctx.channel_id),
+                "guild_xid": str(interaction.guild_id),
+                "channel_xid": str(interaction.channel_id),
             },
         )
 
@@ -330,18 +344,45 @@ async def safe_send_channel(
     with suppress(
         DiscordException,
         log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
-        guild_xid=ctx.guild_id,
-        channel_xid=ctx.channel_id,
+        guild_xid=interaction.guild_id,
+        channel_xid=interaction.channel_id,
     ):
-        message = await ctx.send(*args, **kwargs)
+        await interaction.response.send_message(*args, **kwargs)
+        message = await interaction.original_response()
+    return message
+
+
+@tracer.wrap()
+async def safe_followup_channel(
+    interaction: discord.Interaction,
+    *args: Any,
+    **kwargs: Any,
+) -> Optional[discord.Message]:
+    if span := tracer.current_span():  # pragma: no cover
+        span.set_tags(
+            {
+                "guild_xid": str(interaction.guild_id),
+                "channel_xid": str(interaction.channel_id),
+            },
+        )
+
+    message: Optional[discord.Message] = None
+    with suppress(
+        DiscordException,
+        log="in guild %(guild_xid)s, could not send message to channel %(channel_xid)s",
+        guild_xid=interaction.guild_id,
+        channel_xid=interaction.channel_id,
+    ):
+        await interaction.followup.send(*args, **kwargs)
+        message = await interaction.original_response()
     return message
 
 
 @tracer.wrap()
 async def safe_channel_reply(
     channel: discord.TextChannel,
-    *args,
-    **kwargs,
+    *args: Any,
+    **kwargs: Any,
 ) -> Optional[discord.Message]:
     guild_xid = channel.guild.id
     channel_xid = channel.id
@@ -360,7 +401,7 @@ async def safe_channel_reply(
 
 
 @tracer.wrap()
-async def safe_message_reply(message: discord.Message, *args, **kwargs) -> None:
+async def safe_message_reply(message: discord.Message, *args: Any, **kwargs: Any) -> None:
     if span := tracer.current_span():  # pragma: no cover
         span.set_tags({"messsage_xid": str(message.id)})
 
@@ -377,8 +418,8 @@ async def safe_message_reply(message: discord.Message, *args, **kwargs) -> None:
 @tracer.wrap()
 async def safe_send_user(
     user: Union[discord.User, discord.Member],
-    *args,
-    **kwargs,
+    *args: Any,
+    **kwargs: Any,
 ) -> None:
     user_xid = getattr(user, "id", None)
     if span := tracer.current_span():  # pragma: no cover
@@ -399,13 +440,6 @@ async def safe_send_user(
             user=user,
             exec_info=True,
         )
-    except discord.errors.InvalidArgument as ex:
-        add_span_error(ex)
-        log_warning(
-            "could not send message to user %(user)s",
-            user=user,
-            exec_info=True,
-        )
     except (discord.errors.Forbidden, discord.errors.HTTPException) as ex:
         add_span_error(ex)
         if isinstance(ex, discord.errors.Forbidden) or ex.code == CANT_SEND_CODE:
@@ -416,11 +450,7 @@ async def safe_send_user(
             # by flagging the user until the next time we restart.
             if user_xid is not None:
                 bad_users.add(user_xid)
-            return log_warning(
-                "not allowed to send message to %(user)s",
-                user=user,
-                exec_info=True,
-            )
+            return log_info("not allowed to send message to %(user)s", user=user)
         log_warning(
             "failed to send message to user %(user)s",
             user=user,
@@ -474,10 +504,7 @@ async def safe_add_role(
             return
         if not bot_can_role(guild):
             logger.warning(
-                (
-                    "warning: in guild %s, could not add role: "
-                    "no permissions to add role: %s"
-                ),
+                "warning: in guild %s, could not add role: no permissions to add role: %s",
                 guild.id,
                 str(role),
             )
