@@ -1,9 +1,13 @@
 # pylint: disable=too-many-instance-attributes
+from __future__ import annotations
 
 from datetime import datetime
 from os import getenv
 from typing import Optional
 
+from discord import Object
+from discord.abc import Snowflake
+
 from .environment import running_in_pytest
 
 
@@ -16,6 +20,7 @@ class Settings:
 
         # application
         self.BOT_TOKEN = getenv("BOT_TOKEN")
+        self.BOT_APPLICATION_ID = getenv("BOT_APPLICATION_ID")
         self.PORT = int(getenv("PORT", "3008"))
         self.HOST = getenv("HOST") or "localhost"
         self.DEBUG_GUILD = getenv("DEBUG_GUILD")
@@ -59,7 +64,7 @@ class Settings:
         self.VOICE_GRACE_PERIOD_M = 10  # 10 minutes
         self.VOICE_AGE_LIMIT_H = 5  # 5 hours
         self.VOICE_CLEANUP_LOOP_M = 30  # 30 minutes
-        self.VOICE_CLEANUP_BATCH = 40  # batch size
+        self.VOICE_CLEANUP_BATCH = 30  # batch size
         self.EXPIRE_GAMES_LOOP_M = 10  # 10 minutes
 
     def workaround_over_eager_caching(self, url: str) -> str:
@@ -86,3 +91,7 @@ class Settings:
         return self.workaround_over_eager_caching(
             f"{self.CONTENT_ROOT}/spellbot/main/spellbot-sm.png",
         )
+
+    @property
+    def GUILD_OBJECT(self) -> Optional[Snowflake]:
+        return Object(id=self.DEBUG_GUILD) if self.DEBUG_GUILD else None
